==> wikitty-api-2.0-sources.jar: org/nuiton/wikitty/search/And.java <==
package org.nuiton.wikitty.search;

import java.io.Serializable;
import java.util.List;

/**
 * And operator is used to build conjunctive restriction for request on content.
 * It take at least 2 args. <br>
 * <br>
 * For example, use:
 * <ul>
 * <li>RestrictionHelper.and( restriction1, restriction2 )</li>
 * <li>RestrictionHelper.and( restriction1, restriction2, restriction3 )</li>
 * <li>RestrictionHelper.and(
 * my_JavaUtilList_Of_Restriction_Witch_Size_Is_Upper_Than2 )</li>
 * </ul>
 */
public class And extends Restriction implements Serializable {

    // serialVersionUID is used for serialization.
    private static final long serialVersionUID = 1L;

    protected List<Restriction> restrictions;

    /**
     * Default constructor
     */
    public And() {
        super();
    }

    /**
     * Constructor with all parameters initialized
     * 
     * @param restrictions
     */
    public And(List<Restriction> restrictions) {
        this();
        this.restrictions = restrictions;
    }

    /**
     * Return restrictions
     * 
     * @return
     */
    public List<Restriction> getRestrictions() {
        return restrictions;
    }

    /**
     * Set a value to parameter restrictions.
     * 
     * @param restrictions
     */
    public void setRestrictions(List<Restriction> restrictions) {
        this.restrictions = restrictions;
    }

    /**
     * Equality test based attributes values
     * 
     * @param value
     *            Value to compare
     */
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (!(other instanceof And)) {
            return false;
        }

        final And and = (And) other;

        if ((restrictions == null && and.getRestrictions() != null)
                || (restrictions != null && !restrictions.equals(and
                        .getRestrictions())))
            return false;

        return true;
    }

    public int hashCode() {
        int result = And.class.getName().hashCode();
        if (restrictions != null) {
            result = 29 * result + restrictions.hashCode();
        }
        return result;
    }

}

==> wikitty-api-2.2-sources.jar: org/nuiton/wikitty/search/And.java <==
package org.nuiton.wikitty.search;

import java.io.Serializable;
import java.util.List;

/**
 * And operator is used to build conjunctive restriction for request on content.
 * It take at least 2 args. <br>
 * <br>
 * For example, use:
 * <ul>
 * <li>RestrictionHelper.and( restriction1, restriction2 )</li>
 * <li>RestrictionHelper.and( restriction1, restriction2, restriction3 )</li>
 * <li>RestrictionHelper.and(
 * my_JavaUtilList_Of_Restriction_Witch_Size_Is_Upper_Than2 )</li>
 * </ul>
 */
public class And extends Restriction implements Serializable {

    // serialVersionUID is used for serialization.
    private static final long serialVersionUID = 1L;

    protected List<Restriction> restrictions;

    /**
     * Default constructor
     */
    public And() {
        super();
    }

    /**
     * Constructor with all parameters initialized
     * 
     * @param restrictions
     */
    public And(List<Restriction> restrictions) {
        this();
        this.restrictions = restrictions;
    }

    /**
     * Return restrictions
     * 
     * @return
     */
    public List<Restriction> getRestrictions() {
        return restrictions;
    }

    /**
     * Set a value to parameter restrictions.
     * 
     * @param restrictions
     */
    public void setRestrictions(List<Restriction> restrictions) {
        this.restrictions = restrictions;
    }

    /**
     * Equality test based attributes values
     * 
     * @param value
     *            Value to compare
     */
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (!(other instanceof And)) {
            return false;
        }

        final And and = (And) other;

        if ((restrictions == null && and.getRestrictions() != null)
                || (restrictions != null && !restrictions.equals(and
                        .getRestrictions()))) {
            return false;
        }

        return true;
    }

    public int hashCode() {
        // equals use restrictions but unable to create hashCode from
        // restrictions because it is not
        // constant through time using arbitrary constant hash-code
        return And.class.hashCode();
    }

}
